@@ -1,4 +1,4 @@
-# @(#)$Id: CPANTesting.pm 203 2012-11-13 20:31:44Z pjf $
+# @(#)$Id: CPANTesting.pm 210 2013-04-15 20:24:44Z pjf $
 # Bob-Version: 1.7
 
 package CPANTesting;
@@ -13,17 +13,20 @@ sub is_testing { !! ($ENV{AUTOMATED_TESTING} || $ENV{PERL_CR_SMOKER_CURRENT}
                  || ($ENV{PERL5OPT} || q()) =~ m{ CPAN-Reporter }mx) }
 
 sub should_abort {
+   is_testing() or return 0;
+
+   $host eq q(xphvmfred)
+      and return "Stauner ${host} - cc06993e-a5e9-11e2-83b7-87183f85d660";
    return 0;
 }
 
 sub test_exceptions {
    my $p = shift; is_testing() or return 0;
 
-   $p->{stop_tests} and return 'CPAN Testing stopped in Build.PL';
-
-   $osname eq q(mirbsd)  and return 'Mirbsd  OS unsupported';
-   $host   eq q(slack64) and return "Stopped Bingos ${host}";
-   $host   eq q(falco)   and return "Stopped Bingos ${host}";
+   $p->{stop_tests}      and return 'CPAN Testing stopped in Build.PL';
+   $osname eq q(mirbsd)  and return 'Mirbsd OS unsupported';
+   $host   eq q(slack64) and return "Bingos ${host} - No space left on device";
+   $host   eq q(falco)   and return "Bingos ${host} - No space left on device";
    return 0;
 }
 
